#
# spec file for package gamescope
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without  intree_libs
Name:           gamescope
Version:        3.12.5+git0.a8471d8
Release:        2.1
Summary:        Micro-compositor optimized for running video games on Wayland
License:        BSD-2-Clause
Group:          Amusements/Games/Other
URL:            https://github.com/Plagman/gamescope
Source:         %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  glslang-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  stb-devel
# for xxd
BuildRequires:  vim
%if %{without intree_libs}
BuildRequires:  (pkgconfig(libliftoff) >= 0.4.0 with pkgconfig(libliftoff) < 0.5.0)
BuildRequires:  (pkgconfig(wlroots) >= 0.16.0   with pkgconfig(wlroots) < 0.17.0)
BuildRequires:  pkgconfig(libdisplay-info)
BuildRequires:  pkgconfig(libliftoff)
BuildRequires:  pkgconfig(openvr)
%endif
BuildRequires:  pkgconfig(benchmark)
BuildRequires:  pkgconfig(glm)
BuildRequires:  pkgconfig(hwdata)
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(libdrm) >= 2.4.113
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.17
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xres)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xwayland)
BuildRequires:  pkgconfig(xxf86vm)
%if %{with intree_libs}
BuildRequires:  pkgconfig(xmu)
# from wlroots.spec
BuildRequires:  glslang-devel
BuildRequires:  xorg-x11-server-wayland
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(freerdp2)
BuildRequires:  pkgconfig(gbm) >= 17.1.0
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libdrm) >= 2.4.109
BuildRequires:  pkgconfig(libinput) >= 1.14.0
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libseat)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(vulkan) >= 1.2.182
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.24
BuildRequires:  pkgconfig(wayland-server) >= 1.21
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-composite)
BuildRequires:  pkgconfig(xcb-errors)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-render)
BuildRequires:  pkgconfig(xcb-renderutil)
BuildRequires:  pkgconfig(xcb-xfixes)
BuildRequires:  pkgconfig(xcb-xkb)
BuildRequires:  pkgconfig(xkbcommon)
#/from wlroots.spec
%endif

%description
%{name} is a micro-compositor optimized for running video games on Wayland

%prep
%autosetup -p1

%build
%if 0%{?suse_version} < 1599
sed -i "s|dependency('stb')|declare_dependency(include_directories: include_directories('/usr/include/stb'))|g" src/meson.build
%endif
%meson \
  -Dpipewire=enabled \
%{nil}

%meson_build

%install
%meson_install --skip-subprojects

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_libdir}/libVkLayer_FROG_gamescope_wsi.so
%dir %{_datadir}/vulkan/implicit_layer.d/
%{_datadir}/vulkan/implicit_layer.d/VkLayer_FROG_gamescope_wsi.%{_arch}.json

%changelog
* Wed Sep 13 2023 Callum Farmer <gmbr3@opensuse.org>
- Tumbleweed now has a pkgconfig file for stb
* Fri Sep  1 2023 antonio.teixeira@suse.com
- Update to version 3.12.5+git0.a8471d8:
  * steamcompmgr: Fix build (rebase woes)
  * steamcompmgr: If we have an override surface, make sure new commits are for it
  * Remove reference to non-existent key bind
  * steamcompmgr: Fix disable color mgmt leaving some states behind
  * Only SetSelectionOwner when syncing selections
  * Improve clipboard handling
  * Remove unnecessary key bind
  * Fix build issue
  * Fix documentation
  * Update documentation and --help
* Fri Aug 18 2023 antonio.teixeira@suse.com
- Update to version 3.12.3+git1.77d9432:
  * steamcompmgr: Remove heatmap hard flag when GAMESCOPE_DEBUG_HDR_HEATMAP is set
  * wlserver: Filter out garbage HDR metadata
  * layer: Handle multiple swapchains in QueuePresentKHR
  * steamcompmgr: Force composite when fading
  * layer: add missing header after 540323ac37fc
* Tue Aug 15 2023 antonio.teixeira@suse.com
- Update to version 3.12.1+git1.6fb83bf:
  * color: added atom to control chromatic adaptation mode (default of bradford is unchanged)
  * [color]: removed errant printf
  * [color]: Added support for overriding the apparent (virtual) white point
  * fix clang build break (attempt #2)
  * fix compilation on clang
  * mute format-truncation compile warning
  * glslang: check for renamed bin
  * layer: Support for frame limiter
  * Add info about gamescope packages
  * fix null handle for nul surface
* Sat Jul 29 2023 llyyr.public@gmail.com
- Update to version 3.12.0+git2.50eaf75:
  * Add info about gamescope packages
  * fix null handle for nul surface
  * steamcompmgr: When windows get remapped and were our focus, make sure to re-set them as input focus
  * wlserver: Handle reassignment of wl_id for x11 windows
  * drm: Better fallbacks for external HDR metadata
  * steamcompmgr: Don't fill in app frametime to mangoapp
* Mon Jul 24 2023 llyyr.public@gmail.com
- Update to version 3.12.0~beta10+git12.eb42671:
  * Fix compilation with GCC13
  * steamcompmgr: fix typo
* Mon Jul 10 2023 llyyr.public@gmail.com
- Update to version 3.12.0~beta10+git10.2dd8236:
  * rendervulkan: Use native gamut wideness by default
  * steamcompmgr: Disable force composite when we would partial
  * steamcompmgr: Disable partial composition (for now until some critera are met)
  * drm: Use 10-bit partial composite formats if possible
  * main: Fix CI
  * rendervulkan: Seamless full -> deferred composition switch
  * rendervulkan: Move reset for commandbuffer to main thread for partial composition
  * rendervulkan: Pick right first partial composite image
  * rendervulkan: Use same memory backing for partial and complete composition
  * steamcompmgr, rendervulkan: Implement deferred partial composition
  * drm: Fallback displayColorimetry for broken EDIDs
  * drm: Free blob in fail path
  * steamcompmgr: Fix enabling VRR from commandline
  * drm: Handle not having CRTC 3D LUT/Shaper
* Sat Jun 17 2023 llyyr.public@gmail.com
- Update to version 3.12.0~beta8+git11.789cfc9:
  * main, steamcompmgr: Add support for --headless
  * Added option to set upscaler filter
  * Added option to set upscale scaler
* Wed Jun  7 2023 llyyr.public@gmail.com
- Update to version 3.12.0~beta8+git8.8866c02:
  * vr_session: Add vrsession_set_dashboard_visible
  * steamcompmgr, rendervulkan: Only capture baseplanes in screenshots
  * rendervulkan: Fix half-texel offset for blits
  * rendervulkan: Fix RGB blits using incorrect colorspace
  * rendervulkan: Mark screenshot textures as storage compatible
  * mangoapp: report output size to mangoapp
  * pipewire: Only create up to 8 buffers
  * drm: Don't update internal screen orientation if we don't have one
  * wlserver: Disable trackpad on external screen by default
  * wlserver, drm: Make touchscreen function as trackpad when using external screen
  * drm, wlserver: Always use internal screen rotation for touchscreen orientation
  * rendervulkan: Fix screenshots since moving to 10-bit.
  * steamcompmgr: Remake output images on res change
  * vr_session: Support for trackpad scrolling
* Fri May 26 2023 llyyr.public@gmail.com
- Update to version 3.12.0~beta7+git2.baea00f:
  * [color_helpers]: cleanup tonemapping support
  * Fallback to regular-priority queue when vkCreateDevice fails
* Fri May 19 2023 llyyr.public@gmail.com
- Update to version 3.12.0~beta7+git0.56a7998:
  * steamcompmgr: Fix FSR getting enabled accidentally
  * drm, steamcompmgr: Implement edid patching for HDR for debugging
  * steamcompmgr: Disable EETF tonemapping by default
  * steamcompmgr: Rename atom to GAMESCOPE_COLOR_MANAGEMENT_CHANGING_HINT
  * steamcompmgr: Add GAMESCOPE_COLOR_SLIDER_IN_USE
  * Revert "rendervulkan: Don't use 10-bit format for VR session"
* Tue May 16 2023 llyyr.public@gmail.com
- Update to version 3.12.0~beta3+git42.6586d5e:
  * rendervulkan: Don't use 10-bit format for VR session
  * Pass through duplicate commits if there are feedbacks.
  * Ensure forward progress on frame callback.
  * Ensure that duplicated commits have forward progress.
  * Send presentation after handling commits on XDG.
  * Don't send frame callback before we have actually committed.
  * drm, rendervulkan: Pick a 10-bit format for composite buffer
  * rendervulkan: Expose some more formats
* Sat May 13 2023 llyyr.public@gmail.com
- Update to version 3.12.0~beta3+git34.6531d9c:
  * color_helpers: added default tonemapping for PQ->G22
  * vklayer: added HdrMetadata printing
* Fri May 12 2023 llyyr.public@gmail.com
- Update to version 3.12.0~beta3+git32.941b22f:
  * color_helpers: refactored eetf2390 tonemapping
  * color_helpers: added eetf_2390 tonemapping operator (currently unused)
  * heatmap: fix typo
  * wlserver: Set seat keyboard on keyboard focus
  * main: Fix output initialization for OpenVR
  * fix lut1d header definition
  * dont assume shapers are analytically invertible (uses LUT inverse)
  * main: Don't create SDL Vulkan surface if in a VRSession
  * color_helper: actually store 1d luts in planar form to allow simpler inversion
  * steamcompmgr: Add --framerate-limit
  * color-helpers: all lut computation is in float; quantization is separate step
  * build: Add glm dep to color microbench
  * ci: Add benchmark as a dependency
  * color_helpers: Encode source color EOTF edges once per-edge rather than per-element
  * color_bench: Add color mgmt microbenchmark
  * color_helpers, steamcompmgr: Avoid allocation of LUTs every time we re-setup color mgmt
  * steamcompmgr: Profile all of update_color_mgmt and not just calcColorTransform
  * color_helpers: Apply shaper per-element of nested loop
  * color_helpers: Inline some functions
  * steamcompmgr: Color management microbenchmark
  * color_helpers: Use rintf instead of roundf
  * build: Enable -ffast-math
  * color_helpers: Optimize pq_to_nits + nits_to_pq
  * layer: Enable KHR_present_wait driconf in the layer
  * steamcompmgr: Always send frame callback for any current surface (not just main)
  * wlserver, steamcompmgr: Initial presentation time implementation
  * protocol: Add presentation-time xml + build
  * steamcompmgr: Move send_done to just before latest latch time
  * vulkan: Check if selected queue can be used
* Fri May  5 2023 llyyr.public@gmail.com
- Update to version 3.12.0~beta3+git3.1716555:
  * main: Expose sdr-gamut-wideness and hdr-sdr-content-nits as launch args
  * fix build breakage
  * [color_helpers]: initial implementation of COLOR_LOOK atoms
  * drm: Reset BLEND_TF + BLEND_LUT
  * Avoid out of bounds accesses in drm.cpp
  * layer: Fix scRGB surface format definition
* Mon Apr 24 2023 llyyr.public@gmail.com
- Update to version 3.12.0~beta1+git0.e805c9c:
  * Replace tabs with spaces in help
  * sdlwindow: Gate SDL_GetWindowSizeInPixels behind version check
  * drm: drop unused Linux-only header after a90e359fc477
  * steamcompmgr: Ensure members of steamcompmgr_win_t get initialized
  * main, steamcompmgr, shaders: Handle lack of LUTs + add debug for disabling color mgmt
  * drm: Fix drm_supports_color_mgmt checks
* Sat Apr 22 2023 llyyr.public@gmail.com
- Update to version 3.11.52~beta6+git88.50925d9:
  * shaders: Fix RCAS colorspace
  * updated heatmap_hard appearance
  * added Hard heatmap mode also fixed the heatmap atom parsing
  * drm: Disable BLEND_TF + REGAMMA_TF if single plane
  * drm: Add some chicken bits for color pipeline
  * color_helpers: Remove spaceship operator usage
  * build: Enable -Wno-volatile for GLM
  * docs: Add Steam Deck Display Pipeline graph
  * steamcompmgr: Track needed XFlush across all change properties events
  * steamcompmgr: Expose HDR metadata by feedback atom
  * steamcompmgr, color_helpers: Added atoms for color gains
  * properly map g22 -> g22 luminance when forceHDR is enabled
  * rendervulkan: Fix HDR blur intensity
  * shaders: Fix horizontal blur output colorspace
  * rendervulkan: Fix race when updating LUTs
  * shader: Get blur stuff working with HDR and color mgmt
  * shaders, rendervulkan: Hook up FSR for HDR
  * shaders: Fix scRGBEncodingToPQ
  * steamcompmgr: Fix crash on override LUT
  * shaders: Tetrahedral 3D LUT implementation
  * drm, steamcompmgr: Don't apply color mgmt twice if compositing
  * color, shaders: Use color mgmt LUT path in shader compute path
  * color_helpers: Clean up EOTF definition
  * drm: Fix scRGB handling
  * drm: Always use scale_tf
  * drm, steamcompmgr: Initial EDID patching stuff
  * steamcompmgr: Fix bug where internaldisplaybrightness was not updating when the atom was set
  * steamcompmgr: Fix HDR feedback only updating on mode change
  * steamcompmgr: Minor ITM changes
  * steamcompmgr: Delete GAMESCOPE_DISPLAY_HDR_FORCE_WIDE_GAMMUT_FOR_SDR
  * steamcompmgr: GAMESCOPE_SDR_ON_HDR_CONTENT_BRIGHTNESS atom should be float, not int
  * steamcompmgr: Renamed GAMESCOPE_HDR_SDR_CONTENT_BRIGHTNESS -> GAMESCOPE_SDR_ON_HDR_CONTENT_BRIGHTNESS
  * steamcompmgr: Add GAMESCOPE_COLOR_APP_WANTS_HDR_FEEDBACK
  * color_helpers: Refined sdr gamut generation on wide gamut displays
  * drm: Added envvar to override internal display colorimetry
  * drm: Additional edid logging
  * color_helpers, drm: separated eotf from the colorimetry definition
  * color_helpers: fix brightness mapping for sdr -> sdr
  * drm: Fix disabling HDR on an external HDR display since new color toys
  * color_helpers: Alternate (preferred) check for c++ 2020
  * steamcompmgr: Use proper EOTF enums for the 3dlut overrides
  * steamcompmgr: Use index 0 for lut overrides
  * steamcompmgr: Fix lut3d output override check
  * steamcompmgr, drm: Add support for disjoint content and output encoding colorspaces
  * color_helpers: Fix undefined EOTF for result
  * color_helpers: Don't lerp EOTF
  * color_helpers: Fix EOTF of displaycolorimetry_widegamutgeneric_gamma22
  * drm: Don't use DEGAMMA_TF + SHAPER_TF when we don't need scaling
  * drm: Hook up BLEND_TF and stuff for proper space for degamma
  * color_helpers: WIP on making calcColorTransform PQ aware
  * steamcompmgr: Fix setting lut override multiple times
  * drm: Fix override LUTs
  * color_helpers: Fix scaling SDR content, bodge for PQ + 3D LUT for now
  * drm, steamcompmgr: Move color mgmt state out of DRM
  * drm, color_helpers: Initial support for mixed HDR + SDR planes on both external HDR and fallback SDR when undocked
  * color_helpers: Add pq EOTF math
  * drm: Move to per-plane 3D LUT + Shaper
  * color_helpers: Update color math
  * subprojects: Added glm dependency
  * color, drm: Initial work on new color mgmt system
  * sdlwindow: set icon_surface to nullptr after free
  * sdlwindow: fix HiDPI handling
* Fri Apr  7 2023 llyyr.public@gmail.com
- Update to version 3.11.52~beta6+git26.5d9ecd4:
  * drm: Fix issue on kernels without VALVE1_ HDR extensions
  * drm: Add g_bForceDisableTransferFunctions debug switch
  * shaders: Make blur conditional more obvious
  * rendervulkan: Fix blur with HDR content
  * steamcompmgr: Don't treat LAYERED windows as dropdowns if they have WS_EX_APPWINDOW
* Fri Mar 17 2023 llyyr.public@gmail.com
- Update to version 3.11.52~beta6+git21.f541527:
  * wlserver: Remove accidental debug logging
  * wlserver: Clean up content overrides on surface destroy + support multiple servers for it
  * wlserver: Be more robust when changing override windows
  * steamcompmgr: Fix crash with nested HDR
  * drm: Cleanup HDR TF + MULT state
  * drm: Support HDR_MULT for SDR surfaces
  * drm: Support for HDR with planes with VALVE1_ extension
* Mon Mar 13 2023 llyyr.public@gmail.com
- Update to version 3.11.52~beta6+git14.6f9759a:
  * rendervulkan: Add logging to vulkan_acquire_screenshot_texture
  * sdlwindow: Fix crash on some icon-less windows
  * build: update libdisplay-info pkgconfig filename
  * Add support for DSI internally rotated displays (e.g. GPD)
  * sdlwindow: Fix icon loading
  * vr_session: fix icon loading
  * vr_session, vblankmanager: Sleep vr vblank manager thread if invisible
  * vr_session: Add g_bOpenVRForceInvisible debug switch
* Tue Mar  7 2023 llyyr.public@gmail.com
- Update to version 3.11.52~beta6+git6.659e550:
  * steamcompmgr: Default SDR content brightness to 203
  * drm: add support for headless setup
  * drm: fix return values in drm_prepare()
  * vr_session: fix openvr include
  * build: bump libdisplay-info maximum version
  * build: fix openvr dependency name
  * drm: Only use SDR metadata blob for HDR enabled screens
* Fri Mar  3 2023 llyyr.public@gmail.com
- Update to version 3.11.52~beta5+git0.297245c:
  * steamcompmgr: FSR bodges for HDR
  * steamcompmgr: Allow scanout for some HDR cases
  * drm,wlserver: Fix lifetime of hdr metadata blobs
  * steamcompmgr: Disable tearing if Mangoapp, etc is up (hack)
  * HACK: drm: Always send HDR metadata
  * steamcompmgr: Fix typo in comment
* Thu Feb 23 2023 llyyr.public@gmail.com
- Update to version 3.11.52~beta2+git2.a3dc37f:
  * steamcompmgr: Add workaround for Disgaea PC (405900)
* Tue Feb 21 2023 llyyr.public@gmail.com
- Update to version 3.11.52~beta2+git1.9600bba:
  * build: bump libliftoff to 0.4.0
* Wed Feb 15 2023 llyyr.public@gmail.com
- Update to version 3.11.52~beta2+git0.2a09fbc:
  * steamcompmgr: Replicate EDID path to all servers
* Mon Feb 13 2023 llyyr.public@gmail.com
- Update to version 3.11.52~beta1+git3.b7f5ce9:
  * steamcompmgr: return server ID in xwayland server feedback
  * steamcompmgr: Add support for growing/destroying xwaylands on the fly
  * itm: avoid division by zero for BT.2446 Method A
  * Check for nullptr connector in drm_prepare
* Wed Feb  8 2023 llyyr.public@gmail.com
- Update to version 3.11.51+git135.8a3fa88:
  * wlserver: Treat XKB_KEY_XF86PowerOff as a forbidden key
  * steamcompmgr: xdg-shell fixes
* Fri Feb  3 2023 llyyr.public@gmail.com
- Update to version 3.11.51+git133.d3ce381:
  * steamcompmgr: Fix get_win_display_name
* Mon Jan 30 2023 llyyr.public@gmail.com
- Update to version 3.11.51+git132.ecee87b:
  * wlserver: Add comment about perf of wlserver_get_xdg_shell_windows
  * main: Add --expose-wayland option
  * steamcompmgr: Support for xdg-shell windows
  * steamcompmgr: Add new shared header
  * steamcompmgr: Add std::variant structure for window type
  * wlserver: Initial hookup of xdg-shell
  * rendervulkan: Fix vulkan_create_texture_from_wlr_buffer for cpu ptr path
  * steamcompmgr: Move xwayland-specific window properties to structure
  * drm: use libdisplay-info to parse make/model
  * wlserver: Fix crash on shutdown
* Wed Jan 18 2023 llyyr.public@gmail.com
- Update to version 3.11.51+git117.7bd30dd:
  * add the ability to use inverse tone mapping on apps that output SDR (#751)
  * vr_session: Hook up icon
  * steamcompmgr: Only call updatePosition for the active cursor
  * sdlwindow: Implement icon passthru
  * sdlwindow: Make sure to free cursor surface
  * drm: Hook up "content type" property
  * steamcompmgr: Implement --cursor-scale-height
  * steamcompmgr: Initial groundwork for cursor scale
  * Add support for grabbing the keyboard
* Sun Jan 15 2023 llyyr.public@gmail.com
- Update to version 3.11.51+git108.eff0ac0:
  * wlserver: Add some locking assertions
  * sdlwindow: Add missing lock around wlserver_touchmotion
  * ime: Fix local_ime segfault
  * sdlwindow: Use fake timestamp instead of passing thru
  * ci: Add libxmu
  * sdlwindow: Forward cursor in absolute mode to host compositor
  * main: Fix compilation
  * sdlwindow: Default to non-relative mouse when a cursor image exists
  * sdlwindow: Refactor user events
  * steamcompmgr: Load host cursor by default in nested
* Wed Jan  4 2023 llyyr.public@gmail.com
- Update to version 3.11.51+git74.a1bff9f:
  * shaders: Fix primaries for scRGB content
  * layer: Remove duplicate largestObscuringWindowSize check
  * steamcompmgr: Add GAMESCOPE_HDR_SDR_CONTENT_BRIGHTNESS atom
  * shaders: Improved heatmap code frol Lilium
  * rendervulkan: Apply tonemapping to HDR content on SDR outputs
  * steamcompmgr: Add GAMESCOPE_DEBUG_HDR_HEATMAP
  * color_helpers: Handle naughty clients/EDIDs with more grace
  * main: Add heatmap debug to help
  * subprojects: Update vkroots
  * layer: Clean up return logic in QueuePresentKHR
  * layer: Return result from QueuePresentKHR when not forcing suboptimal
* Mon Jan  2 2023 llyyr.public@gmail.com
- Update to version 3.11.51+git63.acbb719:
  * layer: Enable VK_KHR_xcb_surface extension
  * layer: Add Reply audo-delete helper for XCB replies
  * layer: Free reply in getToplevelWindow when root is reached
  * layer: Free attributeReply after use
  * layer: Add fallback to XCB surface when we cannot safely flip
  * layer: Move XCB helpers to header
  * main: Add hdr-sdr-content-nits argument
  * steamcompmgr: reap children like Linux on some BSDs
  * main: don't renice as non-root on non-Linux
  * shaders: Fix output scaling of heatmap
  * rendervulkan: Framework for configurable SDR on HDR content brightness
  * steamcompmgr: Fix cached value of ST2084 support
  * rendervulkan: Add Lilium's HDR heatmap
  * rendervulkan: Add HDR heatmap debug + way to force support but not PQ output
  * rendervulkan: Turn composite debug into flags rather than bool
  * rendervulkan: Expose 16161616_UNORM format for surfaces
  * layer: Support for x86 and x86_64 builds at the same time
  * build: Add options for building layer/executable
  * layer: Respect vk_x11_override_min_image_count
  * layer: Dump surface state on creation
  * layer: Only expose HDR formats when gamescope HDR output is enabled and it isn't blacklisted for this app
  * steamcompmgr: Add GAMESCOPE_HDR_OUTPUT_FEEDBACK
  * layer: Make getting property values generic
  * layer: Expose scRGB surface format
  * steamcompmgr, rendervulkan: Add force wide gammut option
  * drm: Respect connector HDR capabilities
  * drm: Respect app's HDR metadata
  * drm: Hook up Colorspace and HDR_OUTPUT_METADATA
  * drm, rendervulkan: Hook up composite ST2084 output
  * steamcompmgr, main: Add hdr atoms + startup options
  * drm: Parse out HDR/colorimetry metadata from EDID
  * layer: Use string views
  * layer: Log swapchain format
  * layer: Respect xserver's id when overriding contents
  * protocol, wlserver: Add override_window_content2
  * layer: Hook up SetHDRMetadata
  * protocol: Add set_hdr_metadata to gamescope_xwayland
  * layer: Refactor SynchronizedMapObject usage
  * layer: Minor formatting changes
  * layer: Consolidate extra surface format arrays
  * subprojects: Add libdisplay-info dependency
  * layer: Handle nullptr pApplicationName
  * rendervulkan: Expose R8G8B8A8 surfaces
  * layer: Log colorspace for Gamescope surfaces
  * shaders: Convert primaries for non-HDR10PQ formats when outputting to HDR10PQ
  * rendervulkan: Handle manual sRGB->Linear for formats without SRGB views
  * layer: Fixup currentExtent surface cap + minImageCount
  * layer: Improve logging
  * rendervulkan: Hook up colorspace mask
  * wlserver, steamcompmgr: Track swapchain feedback per-commit
  * wlserver: Use swapchain feedback for tearing
  * layer, wlserver: Implement swapchain feedback
  * layer: Expose HDR10 formats
  * rendervulkan, shaders: Support PQ+scRGB colorspaces + HDR10 output
  * shaders: Add colorimetry helpers
  * rendervulkan: Expose 16161616F format
  * subprojects: Bump vkroots
  * rendervulkan: Expose 1010102 formats
  * sdlwindow: request HiDPI window
  * main: Force disable AMDVLK switchable graphics layer
* Fri Dec 23 2022 llyyr.public@gmail.com
- Update to version 3.11.51+git3.f863708:
  * steamcompmgr: Disable NV12 screenshot hack
  * Wait for POLLIN instead of POLLOUT
  * rendervulkan: print DRM format name
  * wlserver: Fix crash on Steam startup sometimes
  * Fixed stride calculation for NV12 pipewire stream
  * Make sure we don't set the pipewire state to running if there was an error during startup
  * layer: Add gamescope_wsi layer
  * steamcompmgr, drm: Add GAMESCOPE_DISPLAY_EDID_PATH atom
  * wlserver: Allow late binding of content overrides
* Wed Jan 22 2020 Marcus Rueckert <mrueckert@suse.de>
- initial package
